@@ -2,7 +2,7 @@
  * init.c
  * funtions that prepare program workflow and initialization
  *
- * Copyright 2002 Matthias Grimm (joker@cymes.de).
+ * Copyright 2002 Matthias Grimm
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -46,6 +46,8 @@ init_powerprefs(struct basedata *base)
 	base->flags.learn_in_progress = 0;
 	base->learnwindow = NULL;
 	base->profile = &base->ac;
+	base->ac.policy = 0;
+	base->battery.policy = 0;
 
 	if ((rc = ipc_init (LIBMODE_CLIENT, 1)) != 0) {  /* setup IPC subsystem for clients */
 		if (rc == E_NOSERVER)
@@ -116,15 +118,12 @@ install_sighandler ()
 	struct sigaction sa = { {signalhandler}, {{0}}, SA_RESTART, 0 };
 
 	/* install the signal handlers */
-	if (sigaction (SIGINT, &sa, NULL)) {
-		print_error(_("ERROR: Can't install SIGINT handler\n"));
-		return -1;
-	}
-	if (sigaction (SIGTERM, &sa, NULL)) {
-		print_error(_("ERROR: Can't install SIGTERM handler\n"));
-		return -1;
-	}
-	return 0;
+	if (!sigaction (SIGINT, &sa, NULL))
+		if (!sigaction (SIGTERM, &sa, NULL))
+			return 0;
+	
+	print_error(_("ERROR: Can't install signal handler\n"));
+	return -1;
 }
 
 int
@@ -213,6 +212,7 @@ init_guicontrol (struct basedata *base)
 	  { TAG_KBDILLUMONKEY,      "vi_entry_kbdbrightonkey",NULL, th_keyentry,   0},
 	  { TAG_KBDILLUMONMOD,      "vi_entry_kbdbrightonkey",NULL, th_modentry,   0},
 	  { TAG_KBDFADINGSPEED,     "vi_spin_kbdfadespeed",   NULL, th_spinbutton, 0},
+	  { TAG_KBDONBRIGHTNESS,    "vi_spin_kbdstart",       NULL, th_spinbutton, 0},
 	  /* video / autoadjustment */
 	  { TAG_LCDAUTOADJUST,      "vi_check_lcdautoadjust", NULL, th_checkbox,   0},
 	  { TAG_LCDTHRESHOLD,       "vi_spin_lcdthreshold",   NULL, th_spinbutton, 0}, 
@@ -226,9 +226,7 @@ init_guicontrol (struct basedata *base)
 	  { TAG_FRAMEBUFFERDEVICE,  "vi_entry_fbdev",         NULL, th_textentry,  0},
 	  { TAG_BLANKFRAMEBUFFER,   "vi_check_blankfb",       NULL, th_checkbox,   0},
 	  /* power / commands */
-	  { TAG_SCRIPTBATCRITICAL,  "pv_entry_cmdbatcrit",    NULL, th_textentry,  GCF_ROOT},
-	  { TAG_SCRIPTPROFCHANGED,  "pv_entry_cmdchprofile",  NULL, th_textentry,  GCF_ROOT},
-	  { TAG_SCRIPTHDSETUP,      "pv_entry_cmdhdsetup",    NULL, th_textentry,  GCF_ROOT},
+	  { TAG_SCRIPTPMCS,         "pv_entry_cmdchprofile",  NULL, th_textentry,  GCF_ROOT},
 	  { TAG_TIMEFORCMD,         "pv_spin_cmdtimeout",     NULL, th_spinbutton, GCF_ROOT},
 	  /* power / sleeplocks */
 	  { TAG_CPULOADSLEEPLOCK,   "pv_check_cpulock",       NULL, th_checkbox,   0},
@@ -249,25 +247,23 @@ init_guicontrol (struct basedata *base)
 	  { TAG_BWLSECOND,          "pv_spin_secondbwl",      NULL, th_spinbutton, 0},
 	  { TAG_BWLLAST,            "pv_spin_lastbwl",        NULL, th_spinbutton, 0},
 	  /* power / profiles */
-	  { TAG_ONACSLEEP,          "pv_combo_profile",       NULL, th_profile,    0},
-	  { TAG_ONACDIM,            "pv_combo_profile",       NULL, th_profile,    0},
-	  { TAG_ONACCOVERSLEEP,     "pv_combo_profile",       NULL, th_profile,    0},
-	  { TAG_ONACTIMESLEEP,      "pv_combo_profile",       NULL, th_profile,    0},
-	  { TAG_ONACTIMEDIM,        "pv_combo_profile",       NULL, th_profile,    0},
-	  { TAG_ONACTIMEHDOFF,      "pv_combo_profile",       NULL, th_profile,    0},
-	  { TAG_ONBATTERYSLEEP,     "pv_combo_profile",       NULL, th_profile,    0},
-	  { TAG_ONBATTERYDIM,       "pv_combo_profile",       NULL, th_profile,    0},
-	  { TAG_ONBATTERYCOVERSLEEP,"pv_combo_profile",       NULL, th_profile,    0},
-	  { TAG_ONBATTERYTIMESLEEP, "pv_combo_profile",       NULL, th_profile,    0},
-	  { TAG_ONBATTERYTIMEDIM,   "pv_combo_profile",       NULL, th_profile,    0},
-	  { TAG_ONBATTERYTIMEHDOFF, "pv_combo_profile",       NULL, th_profile,    0},
+	  { TAG_ONAC_POLICY,        "pv_combo_profile",       NULL, th_profile,    0},
+	  { TAG_ONAC_TIMERACTION,   "pv_combo_profile",       NULL, th_profile,    0},
+	  { TAG_ONAC_COVERACTION,   "pv_combo_profile",       NULL, th_profile,    0},
+	  { TAG_ONAC_KEYACTION,     "pv_combo_profile",       NULL, th_profile,    0},
+	  { TAG_ONAC_TIMESUSPEND,   "pv_combo_profile",       NULL, th_profile,    0},
+	  { TAG_ONAC_TIMEDIM,       "pv_combo_profile",       NULL, th_profile,    0},
+	  { TAG_ONBATT_POLICY,      "pv_combo_profile",       NULL, th_profile,    0},
+	  { TAG_ONBATT_TIMERACTION, "pv_combo_profile",       NULL, th_profile,    0},
+	  { TAG_ONBATT_COVERACTION, "pv_combo_profile",       NULL, th_profile,    0},
+	  { TAG_ONBATT_KEYACTION,   "pv_combo_profile",       NULL, th_profile,    0},
+	  { TAG_ONBATT_TIMESUSPEND, "pv_combo_profile",       NULL, th_profile,    0},
+	  { TAG_ONBATT_TIMEDIM,     "pv_combo_profile",       NULL, th_profile,    0},
 	  { TAG_HEARTBEATBEEP,      "pv_check_heartbeat",     NULL, th_checkbox,   0},
 	  /* about */
 	  { TAG_VERSION,            "ab_itext_sversion",      NULL, th_showtext,   GCF_RONLY},
 	  /* misc operations through flags*/
-	  { 0,                      "pv_func_cmdbatcrit",     NULL, th_dummy,      GCF_ROOT},
 	  { 0,                      "pv_func_cmdchprofile",   NULL, th_dummy,      GCF_ROOT},
-	  { 0,                      "pv_func_cmdhdsetup",     NULL, th_dummy,      GCF_ROOT},
 	  { 0,                      "pv_func_cmdtimeout",     NULL, th_dummy,      GCF_ROOT},
 	  /* learn buttons */
 	  { 0,  "pv_learn_sleepkey",      "pv_entry_sleepkey",      th_dummy, GCF_LEARN},
@@ -343,18 +339,22 @@ gui_finetuning (struct basedata *base)
 		g_free(text);
 	}
 
+	/* set initial power profile */
+	if ((widget = lookup_widget(base->mainwindow, "pv_combo_profile")))
+		gtk_combo_box_set_active (GTK_COMBO_BOX(widget), 0);
+
 	/* install signal handler which glade-2 is not able to */
-	if ((widget = lookup_widget(base->mainwindow, "pv_radio_sleep")))
-		g_signal_connect (widget, "toggled", G_CALLBACK (cb_update_profile), (gpointer) 0);
-	if ((widget = lookup_widget(base->mainwindow, "pv_check_dim")))
-		g_signal_connect (widget, "toggled", G_CALLBACK (cb_update_profile), (gpointer) 1);
-	if ((widget = lookup_widget(base->mainwindow, "pv_radio_coversleep")))
-		g_signal_connect (widget, "toggled", G_CALLBACK (cb_update_profile), (gpointer) 2);
+	if ((widget = lookup_widget(base->mainwindow, "pv_combo_policy")))
+		g_signal_connect (widget, "changed", G_CALLBACK (cb_update_profile), (gpointer) 0);
+	if ((widget = lookup_widget(base->mainwindow, "pv_combo_timeraction")))
+		g_signal_connect (widget, "changed", G_CALLBACK (cb_update_profile), (gpointer) 1);
+	if ((widget = lookup_widget(base->mainwindow, "pv_combo_coveraction")))
+		g_signal_connect (widget, "changed", G_CALLBACK (cb_update_profile), (gpointer) 2);
+	if ((widget = lookup_widget(base->mainwindow, "pv_combo_keyaction")))
+		g_signal_connect (widget, "changed", G_CALLBACK (cb_update_profile), (gpointer) 3);
 	if ((widget = lookup_widget(base->mainwindow, "pv_spin_sleeptime")))
-		g_signal_connect (widget, "value_changed", G_CALLBACK (cb_update_profile), (gpointer) 3);
-	if ((widget = lookup_widget(base->mainwindow, "pv_spin_dimtime")))
 		g_signal_connect (widget, "value_changed", G_CALLBACK (cb_update_profile), (gpointer) 4);
-	if ((widget = lookup_widget(base->mainwindow, "pv_spin_hdofftime")))
+	if ((widget = lookup_widget(base->mainwindow, "pv_spin_dimtime")))
 		g_signal_connect (widget, "value_changed", G_CALLBACK (cb_update_profile), (gpointer) 5);
 
 	if ((widget = lookup_widget(base->mainwindow, "main_btn_apply")))
